/*
 * qwine-parse.h: Parse the output of wine's autoctl channel and
 * create external windows to monitor the progress.  Currently only
 * implements a progress dialog.
 *
 * See qwine-parse.cc for instructions on compiling and running.
 *
 * John R. Sheets <jsheets@codeweavers.com>
 */

#include <qapplication.h>
#include <qsemimodal.h>
#include <qtextstream.h>
#include <qtimer.h>
#include <qlabel.h>
#include <qprogressbar.h>
#include <qfile.h>

class TimerProgressDialog : public QSemiModal
{
    Q_OBJECT

public:
    TimerProgressDialog (const QString &labelText);
    bool handleInput (const QString &line);

private:
    // Run 'autoctl' commands
    void doCreate (const QString &command);
    void doIncrement (const QString &command);
    void closeEvent (QCloseEvent *e);

private:
    // Input stream (usually stdin)
    QLabel *m_label;
    QLabel *m_label2;
    QProgressBar *m_progressBarFont;
    QProgressBar *m_progressBarModule;
};

class ProgressGUI : public QWidget
{
    Q_OBJECT

public:
    ProgressGUI (const QString &labelText, QTextIStream *istr);

public slots:
    // Slot for QTimer
    void handleInput ();

private:
    QTextIStream *m_istr;
    TimerProgressDialog *m_progressDlg;
    QString m_messageLog;
};
